@@ -1,8 +1,9 @@
 # flake8: noqa
 from .table_utils import (
+    check_empty_box_plot_dict,
     is_property,
     is_public_method,
     mi_between_cols,
     to_pandas,
-    validate_subset_schema
+    validate_subset_schema,
 )
